from typing import Optional, List
from ..base import BaseAPI, BaseResponse, ListResponse, PaginatedListResponse
from .models import *

class NBATeamsAPI(BaseAPI[NBATeam]):
    model_class = NBATeam

    def list(
        self, 
        division: Optional[str] = None, 
        conference: Optional[str] = None
    ) -> ListResponse[NBATeam]:
        return self._get_list("nba/v1/teams", {
            "division": division,
            "conference": conference
        })

    def get(self, team_id: int) -> BaseResponse[NBATeam]:
        return self._get_data(f"nba/v1/teams/{team_id}")

class NBAPlayersAPI(BaseAPI[NBAPlayer]):
    model_class = NBAPlayer

    def list(
        self,
        cursor: Optional[int] = None,
        per_page: Optional[int] = 25,
        team_ids: Optional[List[int]] = None,
        player_ids: Optional[List[int]] = None,
        search: Optional[str] = None,
        first_name: Optional[str] = None,
        last_name: Optional[str] = None
    ) -> PaginatedListResponse[NBAPlayer]:
        return self._get_paginated_list("nba/v1/players", {
            "cursor": cursor,
            "per_page": per_page,
            "team_ids": team_ids,
            "player_ids": player_ids,
            "search": search,
            "first_name": first_name,
            "last_name": last_name
        })

    def get(self, player_id: int) -> BaseResponse[NBAPlayer]:
        return self._get_data(f"nba/v1/players/{player_id}")

    def list_active(
        self,
        cursor: Optional[int] = None,
        per_page: Optional[int] = 25,
        team_ids: Optional[List[int]] = None,
        player_ids: Optional[List[int]] = None,
        search: Optional[str] = None,
        first_name: Optional[str] = None,
        last_name: Optional[str] = None
    ) -> PaginatedListResponse[NBAPlayer]:
        return self._get_paginated_list("nba/v1/players/active", {
            "cursor": cursor,
            "per_page": per_page,
            "team_ids": team_ids,
            "player_ids": player_ids,
            "search": search,
            "first_name": first_name,
            "last_name": last_name
        })

class NBAGamesAPI(BaseAPI[NBAGame]):
    model_class = NBAGame

    def list(
        self,
        cursor: Optional[int] = None,
        per_page: Optional[int] = 25,
        dates: Optional[List[str]] = None,
        team_ids: Optional[List[int]] = None,
        seasons: Optional[List[int]] = None,
        postseason: Optional[bool] = None,
        start_date: Optional[str] = None,
        end_date: Optional[str] = None
    ) -> PaginatedListResponse[NBAGame]:
        return self._get_paginated_list("nba/v1/games", {
            "cursor": cursor,
            "per_page": per_page,
            "dates": dates,
            "team_ids": team_ids,
            "seasons": seasons,
            "postseason": postseason,
            "start_date": start_date,
            "end_date": end_date
        })

    def get(self, game_id: int) -> BaseResponse[NBAGame]:
        return self._get_data(f"nba/v1/games/{game_id}")

class NBAStatsAPI(BaseAPI[NBAStats]):
    model_class = NBAStats

    def list(
        self,
        cursor: Optional[int] = None,
        per_page: Optional[int] = 25,
        player_ids: Optional[List[int]] = None,
        game_ids: Optional[List[int]] = None,
        dates: Optional[List[str]] = None,
        seasons: Optional[List[int]] = None,
        postseason: Optional[bool] = None,
        start_date: Optional[str] = None,
        end_date: Optional[str] = None
    ) -> PaginatedListResponse[NBAStats]:
        return self._get_paginated_list("nba/v1/stats", {
            "cursor": cursor,
            "per_page": per_page,
            "player_ids": player_ids,
            "game_ids": game_ids,
            "dates": dates,
            "seasons": seasons,
            "postseason": postseason,
            "start_date": start_date,
            "end_date": end_date
        })

class NBASeasonAveragesAPI(BaseAPI[NBASeasonAverages]):
    model_class = NBASeasonAverages

    def get(self, season: int, player_id: int) -> ListResponse[NBASeasonAverages]:
        return self._get_list("nba/v1/season_averages", {
            "season": season,
            "player_id": player_id
        })

class NBAStandingsAPI(BaseAPI[NBAStandings]):
    model_class = NBAStandings

    def get(self, season: int) -> ListResponse[NBAStandings]:
        return self._get_list("nba/v1/standings", {
            "season": season
        })

class NBABoxScoresAPI(BaseAPI[NBABoxScore]):
    model_class = NBABoxScore

    def get_live(self) -> ListResponse[NBABoxScore]:
        return self._get_list("nba/v1/box_scores/live")

    def get_by_date(self, date: str) -> ListResponse[NBABoxScore]:
        return self._get_list("nba/v1/box_scores", {
            "date": date
        })

class NBAPlayerInjuriesAPI(BaseAPI[NBAPlayerInjury]):
    model_class = NBAPlayerInjury

    def list(
        self,
        cursor: Optional[int] = None,
        per_page: Optional[int] = 25,
        team_ids: Optional[List[int]] = None,
        player_ids: Optional[List[int]] = None
    ) -> PaginatedListResponse[NBAPlayerInjury]:
        return self._get_paginated_list("nba/v1/player_injuries", {
            "cursor": cursor,
            "per_page": per_page,
            "team_ids": team_ids,
            "player_ids": player_ids
        })

class NBALeadersAPI(BaseAPI[NBALeader]):
    model_class = NBALeader

    def get(self, stat_type: str, season: int) -> ListResponse[NBALeader]:
        return self._get_list("nba/v1/leaders", {
            "stat_type": stat_type,
            "season": season
        })

class NBAOddsAPI(BaseAPI[NBAOdds]):
    model_class = NBAOdds

    def list(
        self, 
        date: Optional[str] = None, 
        game_id: Optional[int] = None
    ) -> ListResponse[NBAOdds]:
        return self._get_list("nba/v1/odds", {
            "date": date,
            "game_id": game_id
        })

class NBAAdvancedStatsAPI(BaseAPI[NBAAdvancedStats]):
    model_class = NBAAdvancedStats

    def list(
        self,
        cursor: Optional[int] = None,
        per_page: Optional[int] = 25,
        player_ids: Optional[List[int]] = None,
        game_ids: Optional[List[int]] = None,
        dates: Optional[List[str]] = None,
        seasons: Optional[List[int]] = None,
        postseason: Optional[bool] = None
    ) -> PaginatedListResponse[NBAAdvancedStats]:
        return self._get_paginated_list("nba/v1/stats/advanced", {
            "cursor": cursor,
            "per_page": per_page,
            "player_ids": player_ids,
            "game_ids": game_ids,
            "dates": dates,
            "seasons": seasons,
            "postseason": postseason
        })

class NBAApi:
    def __init__(self, client):
        self.teams = NBATeamsAPI(client)
        self.players = NBAPlayersAPI(client)
        self.games = NBAGamesAPI(client)
        self.stats = NBAStatsAPI(client)
        self.season_averages = NBASeasonAveragesAPI(client)
        self.standings = NBAStandingsAPI(client)
        self.box_scores = NBABoxScoresAPI(client)
        self.injuries = NBAPlayerInjuriesAPI(client)
        self.leaders = NBALeadersAPI(client)
        self.odds = NBAOddsAPI(client)
        self.advanced_stats = NBAAdvancedStatsAPI(client)


from typing import Optional
from pydantic import BaseModel

class NFLTeam(BaseModel):
    id: int
    conference: str
    division: str
    location: str
    name: str
    full_name: str
    abbreviation: str

class NFLPlayer(BaseModel):
    id: int
    first_name: str
    last_name: str
    position: str
    position_abbreviation: str
    height: str
    weight: str
    jersey_number: Optional[str]
    college: Optional[str]
    experience: Optional[str]
    age: Optional[int]
    team: Optional[NFLTeam] = None
    team_id: Optional[int] = None

class NFLGame(BaseModel):
    id: int
    visitor_team: NFLTeam
    home_team: NFLTeam
    summary: Optional[str]
    venue: Optional[str]
    week: int
    date: str
    season: int
    postseason: bool
    status: str
    home_team_score: Optional[int]
    home_team_q1: Optional[int]
    home_team_q2: Optional[int]
    home_team_q3: Optional[int]
    home_team_q4: Optional[int]
    home_team_ot: Optional[int]
    visitor_team_score: Optional[int]
    visitor_team_q1: Optional[int]
    visitor_team_q2: Optional[int]
    visitor_team_q3: Optional[int]
    visitor_team_q4: Optional[int]
    visitor_team_ot: Optional[int]

class NFLStats(BaseModel):
    player: NFLPlayer
    team: NFLTeam
    game: NFLGame
    passing_completions:     Optional[int]
    passing_attempts:        Optional[int]
    passing_yards:           Optional[int]
    yards_per_pass_attempt:  Optional[float]
    passing_touchdowns:      Optional[int]
    passing_interceptions:   Optional[int]
    sacks:                   Optional[int]
    sacks_loss:              Optional[int]
    qbr:                     Optional[float]
    qb_rating:               Optional[float]
    rushing_attempts:        Optional[int]
    rushing_yards:           Optional[int]
    yards_per_rush_attempt:  Optional[float]
    rushing_touchdowns:      Optional[int]
    long_rushing:            Optional[int]
    receptions:              Optional[int]
    receiving_yards:         Optional[int]
    yards_per_reception:     Optional[float]
    receiving_touchdowns:    Optional[int]
    long_reception:          Optional[int]
    receiving_targets:       Optional[int]
    fumbles:                 Optional[int]
    fumbles_lost:            Optional[int]
    fumbles_recovered:       Optional[int]
    total_tackles:           Optional[int]
    defensive_sacks:         Optional[int]
    solo_tackles:            Optional[int]
    tackles_for_loss:        Optional[int]
    passes_defended:         Optional[int]
    qb_hits:                 Optional[int]
    fumbles_touchdowns:      Optional[int]
    defensive_interceptions: Optional[int]
    interception_yards:      Optional[int]
    interception_touchdowns: Optional[int]
    kick_returns:            Optional[int]
    kick_return_yards:       Optional[int]
    yards_per_kick_return:   Optional[float]
    long_kick_return:        Optional[int]
    kick_return_touchdowns:  Optional[int]
    punt_returns:            Optional[int]
    punt_return_yards:       Optional[int]
    yards_per_punt_return:   Optional[float]
    long_punt_return:        Optional[int]
    punt_return_touchdowns:  Optional[int]
    field_goal_attempts:     Optional[int]
    field_goals_made:        Optional[int]
    field_goal_pct:          Optional[int]
    long_field_goal_made:    Optional[int]
    extra_points_made:       Optional[int]
    total_points:            Optional[int]
    punts:                   Optional[int]
    punt_yards:              Optional[int]
    gross_avg_punt_yards:    Optional[float]
    touchbacks:              Optional[int]
    punts_inside_20:         Optional[int]
    long_punt:               Optional[int]

class NFLStandings(BaseModel):
    team: NFLTeam
    win_streak: int
    points_for: int
    points_against: int
    playoff_seed: Optional[int]
    point_differential: int
    overall_record: str
    conference_record: str
    division_record: str
    wins: int
    losses: int
    ties: int
    home_record: str
    road_record: str
    season: int

class NFLPlayerInjury(BaseModel):
    player: NFLPlayer
    status: str
    comment: str
    date: str

class NFLSeasonStats(BaseModel):
    player: NFLPlayer
    games_played: int
    season: int
    postseason: bool
    passing_completions:                        Optional[int]
    passing_attempts:                           Optional[int]
    passing_yards:                              Optional[int]
    yards_per_pass_attempt:                     Optional[float]
    passing_touchdowns:                         Optional[int]
    passing_interceptions:                      Optional[int]
    passing_yards_per_game:                     Optional[float]
    passing_completion_pct:                     Optional[float]
    qbr:                                        Optional[float]
    rushing_attempts:                           Optional[int]
    rushing_yards:                              Optional[int]
    rushing_yards_per_game:                     Optional[float]
    yards_per_rush_attempt:                     Optional[float]
    rushing_touchdowns:                         Optional[int]
    rushing_fumbles:                            Optional[int]
    rushing_fumbles_lost:                       Optional[int]
    rushing_first_downs:                        Optional[int]
    receptions:                                 Optional[int]
    receiving_yards:                            Optional[int]
    yards_per_reception:                        Optional[float]
    receiving_touchdowns:                       Optional[int]
    receiving_fumbles:                          Optional[int]
    receiving_fumbles_lost:                     Optional[int]
    receiving_first_downs:                      Optional[int]
    receiving_targets:                          Optional[int]
    receiving_yards_per_game:                   Optional[float]
    fumbles_forced:                             Optional[int]
    fumbles_recovered:                          Optional[int]
    total_tackles:                              Optional[int]
    defensive_sacks:                            Optional[float]
    defensive_sack_yards:                       Optional[int]
    solo_tackles:                               Optional[int]
    assist_tackles:                             Optional[int]
    fumbles_touchdowns:                         Optional[int]
    defensive_interceptions:                    Optional[int]
    interception_touchdowns:                    Optional[int]
    kick_returns:                               Optional[int]
    kick_return_yards:                          Optional[float]
    yards_per_kick_return:                      Optional[float]
    kick_return_touchdowns:                     Optional[int]
    punt_returner_returns:                      Optional[int]
    punt_returner_return_yards:                 Optional[int]
    yards_per_punt_return:                      Optional[float]
    punt_return_touchdowns:                     Optional[int]
    field_goal_attempts:                        Optional[int]
    field_goals_made:                           Optional[int]
    field_goal_pct:                             Optional[float]
    punts:                                      Optional[int]
    punt_yards:                                 Optional[int]
    field_goals_made_1_19:                      Optional[int]
    field_goals_made_20_29:                     Optional[int]
    field_goals_made_30_39:                     Optional[int]
    field_goals_made_40_49:                     Optional[int]
    field_goals_made_50:                        Optional[int]
    field_goals_attempts_1_19:                  Optional[int]
    field_goals_attempts_20_29:                 Optional[int]
    field_goals_attempts_30_39:                 Optional[int]
    field_goals_attempts_40_49:                 Optional[int]
    field_goals_attempts_50:                    Optional[int]

class NFLAdvancedRushingStats(BaseModel):
    player: NFLPlayer
    season: int
    week: int
    avg_time_to_los: Optional[float]
    expected_rush_yards: Optional[float]
    rush_attempts: Optional[int]
    rush_pct_over_expected: Optional[float]
    rush_touchdowns: Optional[int]
    rush_yards: Optional[int]
    rush_yards_over_expected: Optional[float]
    rush_yards_over_expected_per_att: Optional[float]
    efficiency: Optional[float]
    percent_attempts_gte_eight_defenders: Optional[float]
    avg_rush_yards: Optional[float]

class NFLAdvancedPassingStats(BaseModel):
    player: NFLPlayer
    season: int
    week: int
    aggressiveness: Optional[float]
    attempts: Optional[int]
    avg_air_distance: Optional[float]
    avg_air_yards_differential: Optional[float]
    avg_air_yards_to_sticks: Optional[float]
    avg_completed_air_yards: Optional[float]
    avg_intended_air_yards: Optional[float]
    avg_time_to_throw: Optional[float]
    completion_percentage: Optional[float]
    completion_percentage_above_expectation: Optional[float]
    completions: Optional[int]
    expected_completion_percentage: Optional[float]
    games_played: Optional[int]
    interceptions: Optional[int]
    max_air_distance: Optional[float]
    max_completed_air_distance: float
    pass_touchdowns: Optional[int]
    pass_yards: Optional[int]
    passer_rating: Optional[float]

class NFLAdvancedReceivingStats(BaseModel):
    player: NFLPlayer
    season: int
    week: int
    avg_cushion: Optional[float]
    avg_expected_yac: Optional[float]
    avg_intended_air_yards: Optional[float]
    avg_separation: Optional[float]
    avg_yac: Optional[float]
    avg_yac_above_expectation: Optional[float]
    catch_percentage: Optional[float]
    percent_share_of_intended_air_yards: Optional[float]
    rec_touchdowns: Optional[int]
    receptions: Optional[int]
    targets: Optional[int]
    yards: Optional[int]


from typing import Optional, List
from pydantic import BaseModel

class NBATeam(BaseModel):
    id: int
    conference: str
    division: str
    city: str
    name: str
    full_name: str
    abbreviation: str

class NBAPlayer(BaseModel):
    id: int
    first_name: Optional[str]
    last_name: Optional[str]
    position: Optional[str]
    height: Optional[str]
    weight: Optional[str]
    jersey_number: Optional[str]
    college: Optional[str]
    country: Optional[str]
    draft_year: Optional[int]
    draft_round: Optional[int]
    draft_number: Optional[int]
    team: Optional[NBATeam] = None
    team_id: Optional[int] = None

class NBAGame(BaseModel):
    id: int
    date: str
    season: int
    status: str
    period: int
    time: Optional[str] 
    postseason: bool
    home_team_score: int
    visitor_team_score: int
    home_team: Optional[NBATeam] = None
    home_team_id: Optional[int] = None
    visitor_team: Optional[NBATeam] = None
    visitor_team_id: Optional[int] = None

class NBAStats(BaseModel):
    id: Optional[int] = None
    min: Optional[str]
    fgm: Optional[int]
    fga: Optional[int]
    fg_pct: Optional[float]
    fg3m: Optional[int]
    fg3a: Optional[int]
    fg3_pct: Optional[float]
    ftm: Optional[int]
    fta: Optional[int]
    ft_pct: Optional[float]
    oreb: Optional[int]
    dreb: Optional[int]
    reb: Optional[int]
    ast: Optional[int]
    stl: Optional[int]
    blk: Optional[int]
    turnover: Optional[int]
    pf: Optional[int]
    pts: Optional[int]
    player: NBAPlayer
    team: Optional[NBATeam] = None
    game: Optional[NBAGame] = None

class NBASeasonAverages(BaseModel):
    games_played: int
    pts: Optional[float]
    ast: Optional[float]
    reb: Optional[float]
    stl: Optional[float]
    blk: Optional[float]
    turnover: Optional[float]
    min: str
    fgm: Optional[float]
    fga: Optional[float]
    fg_pct: Optional[float]
    fg3m: Optional[float]
    fg3a: Optional[float]
    fg3_pct: Optional[float]
    ftm: Optional[float]
    fta: Optional[float]
    ft_pct: Optional[float]
    oreb: Optional[float]
    dreb: Optional[float]
    player_id: int
    season: int

class NBAStandings(BaseModel):
    team: NBATeam
    conference_record: str
    conference_rank: int
    division_record: str
    division_rank: int
    wins: int
    losses: int
    home_record: str
    road_record: str
    season: int

class NBABoxScoreTeam(NBATeam):
    players: List[NBAStats]

class NBABoxScore(BaseModel):
    date: str
    season: int
    status: str
    period: int
    time: Optional[str]
    postseason: bool
    home_team_score: int
    visitor_team_score: int
    home_team: NBABoxScoreTeam
    visitor_team: NBABoxScoreTeam

class NBAPlayerInjury(BaseModel):
    player: NBAPlayer
    return_date: Optional[str]
    description: str
    status: str

class NBALeader(BaseModel):
    player: NBAPlayer
    value: float
    stat_type: str
    rank: int
    season: int
    games_played: int

class NBAOdds(BaseModel):
    type: str
    vendor: str
    live: bool
    game_id: int
    odds_decimal_home: Optional[str]
    odds_decimal_visitor: Optional[str]
    odds_american_home: Optional[str]
    odds_american_visitor: Optional[str]
    away_spread: Optional[str] = None
    over_under: Optional[str] = None

class NBAAdvancedStats(BaseModel):
    id: int
    pie: Optional[float]
    pace: Optional[float]
    assist_percentage: Optional[float]
    assist_ratio: Optional[float]
    assist_to_turnover: Optional[float]
    defensive_rating: Optional[float]
    defensive_rebound_percentage: Optional[float]
    effective_field_goal_percentage: Optional[float]
    net_rating: Optional[float]
    offensive_rating: Optional[float]
    offensive_rebound_percentage: Optional[float]
    rebound_percentage: Optional[float]
    true_shooting_percentage: Optional[float]
    turnover_ratio: Optional[float]
    usage_percentage: Optional[float]
    player: NBAPlayer
    team: NBATeam
    game: NBAGame


from typing import Optional, List
from ..base import BaseAPI, BaseResponse, ListResponse, PaginatedListResponse
from .models import *

class NFLTeamsAPI(BaseAPI[NFLTeam]):
    model_class = NFLTeam

    def list(
        self, 
        division: Optional[str] = None, 
        conference: Optional[str] = None
    ) -> ListResponse[NFLTeam]:
        return self._get_list("nfl/v1/teams", {
            "division": division,
            "conference": conference
        })

    def get(self, team_id: int) -> BaseResponse[NFLTeam]:
        return self._get_data(f"nfl/v1/teams/{team_id}")

class NFLPlayersAPI(BaseAPI[NFLPlayer]):
    model_class = NFLPlayer

    def list(
        self,
        cursor: Optional[int] = None,
        per_page: Optional[int] = 25,
        team_ids: Optional[List[int]] = None,
        player_ids: Optional[List[int]] = None,
        search: Optional[str] = None,
        first_name: Optional[str] = None,
        last_name: Optional[str] = None
    ) -> PaginatedListResponse[NFLPlayer]:
        return self._get_paginated_list("nfl/v1/players", {
            "cursor": cursor,
            "per_page": per_page,
            "team_ids": team_ids,
            "player_ids": player_ids,
            "search": search,
            "first_name": first_name,
            "last_name": last_name
        })

    def get(self, player_id: int) -> BaseResponse[NFLPlayer]:
        return self._get_data(f"nfl/v1/players/{player_id}")

    def list_active(
        self,
        cursor: Optional[int] = None,
        per_page: Optional[int] = 25,
        team_ids: Optional[List[int]] = None,
        player_ids: Optional[List[int]] = None,
        search: Optional[str] = None,
        first_name: Optional[str] = None,
        last_name: Optional[str] = None
    ) -> PaginatedListResponse[NFLPlayer]:
        return self._get_paginated_list("nfl/v1/players/active", {
            "cursor": cursor,
            "per_page": per_page,
            "team_ids": team_ids,
            "player_ids": player_ids,
            "search": search,
            "first_name": first_name,
            "last_name": last_name
        })

class NFLGamesAPI(BaseAPI[NFLGame]):
    model_class = NFLGame

    def list(
        self,
        cursor: Optional[int] = None,
        per_page: Optional[int] = 25,
        dates: Optional[List[str]] = None,
        team_ids: Optional[List[int]] = None,
        seasons: Optional[List[int]] = None,
        postseason: Optional[bool] = None,
        weeks: Optional[List[int]] = None
    ) -> PaginatedListResponse[NFLGame]:
        return self._get_paginated_list("nfl/v1/games", {
            "cursor": cursor,
            "per_page": per_page,
            "dates": dates,
            "team_ids": team_ids,
            "seasons": seasons,
            "postseason": postseason,
            "weeks": weeks
        })

    def get(self, game_id: int) -> BaseResponse[NFLGame]:
        return self._get_data(f"nfl/v1/games/{game_id}")

class NFLStatsAPI(BaseAPI[NFLStats]):
    model_class = NFLStats

    def list(
        self,
        cursor: Optional[int] = None,
        per_page: Optional[int] = 25,
        player_ids: Optional[List[int]] = None,
        game_ids: Optional[List[int]] = None,
        seasons: Optional[List[int]] = None
    ) -> PaginatedListResponse[NFLStats]:
        return self._get_paginated_list("nfl/v1/stats", {
            "cursor": cursor,
            "per_page": per_page,
            "player_ids": player_ids,
            "game_ids": game_ids,
            "seasons": seasons
        })

class NFLStandingsAPI(BaseAPI[NFLStandings]):
    model_class = NFLStandings

    def get(self, season: int) -> ListResponse[NFLStandings]:
        return self._get_list("nfl/v1/standings", {
            "season": season
        })

class NFLPlayerInjuriesAPI(BaseAPI[NFLPlayerInjury]):
    model_class = NFLPlayerInjury

    def list(
        self,
        cursor: Optional[int] = None,
        per_page: Optional[int] = 25,
        team_ids: Optional[List[int]] = None,
        player_ids: Optional[List[int]] = None
    ) -> PaginatedListResponse[NFLPlayerInjury]:
        return self._get_paginated_list("nfl/v1/player_injuries", {
            "cursor": cursor,
            "per_page": per_page,
            "team_ids": team_ids,
            "player_ids": player_ids
        })

class NFLSeasonStatsAPI(BaseAPI[NFLSeasonStats]):
    model_class = NFLSeasonStats

    def list(
        self,
        season: int,
        player_ids: Optional[List[int]] = None,
        team_id: Optional[int] = None,
        postseason: Optional[bool] = None,
        sort_by: Optional[str] = None,
        sort_order: Optional[str] = None
    ) -> PaginatedListResponse[NFLSeasonStats]:
        return self._get_paginated_list("nfl/v1/season_stats", {
            "season": season,
            "player_ids": player_ids,
            "team_id": team_id,
            "postseason": postseason,
            "sort_by": sort_by,
            "sort_order": sort_order
        })

class NFLAdvancedRushingStatsAPI(BaseAPI[NFLAdvancedRushingStats]):
    model_class = NFLAdvancedRushingStats

    def get(
        self,
        season: int,
        player_id: Optional[int] = None,
        week: Optional[int] = None
    ) -> PaginatedListResponse[NFLAdvancedRushingStats]:
        return self._get_paginated_list("nfl/v1/advanced_stats/rushing", {
            "season": season,
            "player_id": player_id,
            "week": week
        })

class NFLAdvancedPassingStatsAPI(BaseAPI[NFLAdvancedPassingStats]):
    model_class = NFLAdvancedPassingStats

    def get(
        self,
        season: int,
        player_id: Optional[int] = None,
        week: Optional[int] = None
    ) -> PaginatedListResponse[NFLAdvancedPassingStats]:
        return self._get_paginated_list("nfl/v1/advanced_stats/passing", {
            "season": season,
            "player_id": player_id,
            "week": week
        })

class NFLAdvancedReceivingStatsAPI(BaseAPI[NFLAdvancedReceivingStats]):
    model_class = NFLAdvancedReceivingStats

    def get(
        self,
        season: int,
        player_id: Optional[int] = None,
        week: Optional[int] = None
    ) -> PaginatedListResponse[NFLAdvancedReceivingStats]:
        return self._get_paginated_list("nfl/v1/advanced_stats/receiving", {
            "season": season,
            "player_id": player_id,
            "week": week
        })

class NFLAdvancedStatsAPI:
    def __init__(self, client):
        self.rushing = NFLAdvancedRushingStatsAPI(client)
        self.passing = NFLAdvancedPassingStatsAPI(client)
        self.receiving = NFLAdvancedReceivingStatsAPI(client)

class NFLApi:
    def __init__(self, client):
        self.teams = NFLTeamsAPI(client)
        self.players = NFLPlayersAPI(client)
        self.games = NFLGamesAPI(client)
        self.stats = NFLStatsAPI(client)
        self.standings = NFLStandingsAPI(client)
        self.injuries = NFLPlayerInjuriesAPI(client)
        self.season_stats = NFLSeasonStatsAPI(client)
        self.advanced_stats = NFLAdvancedStatsAPI(client)